OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "リクエストトークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "アクセストークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Please provide a valid app key and secret." : "有効なアプリのキーとパスワードを入力してください。",
    "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
    "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
    "External storage" : "外部ストレージ",
    "Dropbox App Configuration" : "Dropbox アプリ設定",
    "Google Drive App Configuration" : "Google アプリ設定",
    "Personal" : "個人",
    "System" : "システム",
    "Grant access" : "アクセスを許可",
    "Error configuring OAuth1" : "OAuth1設定エラー",
    "Error configuring OAuth2" : "OAuth2 設定エラー",
    "Generate keys" : "キーを生成",
    "Error generating key pair" : "キーペアの生成エラー",
    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
    "(group)" : "(グループ)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
    "Admin defined" : "管理者設定済",
    "Saved" : "保存されました",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "外部ストレージを無効化すると、すべてのユーザーに影響を与えます。続行しますか？",
    "Disable external storage" : "外部ストレージを無効化",
    "Empty response from the server" : "サーバーから空の応答がありました",
    "Couldn't access. Please logout and login to activate this mount point" : "アクセスできません｡このマウントポイントを有効にするには、一度ログアウトしてからログインしてください。",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloudサーバーから情報を取得できません: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得できません: {type}",
    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
    "External mount error" : "外部マウントエラー",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windowsネットワークドライブのマウントポイントリストを取得できません:サーバーから空の応答がありました",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
    "Please enter the credentials for the {mount} mount" : " {mount} をマウントするための必要な資格情報を入力してください",
    "Username" : "ユーザー名",
    "Password" : "パスワード",
    "Credentials saved" : "資格情報を保存しました",
    "Credentials saving failed" : "資格情報の保存に失敗しました",
    "Credentials required" : "資格情報が必要です",
    "Save" : "保存",
    "Storage with id \"%i\" not found" : "ストレージID \"%i\" が見つかりません",
    "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
    "Invalid mount point" : "無効なマウントポイント",
    "Objectstore forbidden" : "オブジェクトストアが禁じられています",
    "Invalid storage backend \"%s\"" : "\"%s\" のストレージバックエンドが不正",
    "Not permitted to use backend \"%s\"" : "バックエンド %s を使うための権限がありません",
    "Not permitted to use authentication mechanism \"%s\"" : "認証システム %s を使う権限がありません",
    "Unsatisfied backend parameters" : "バックエンドのためのパラメーターが不十分です。",
    "Unsatisfied authentication mechanism parameters" : "認証のためのパラメータが不十分です",
    "Insufficient data: %s" : "データが不足しています: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "ストレージID \"%i\" はユーザーが編集できません",
    "Access key" : "アクセスキー",
    "Secret key" : "シークレットキー",
    "OAuth1" : "OAuth1",
    "App key" : "アプリキー",
    "App secret" : "アプリシークレット",
    "OAuth2" : "OAuth2",
    "Client ID" : "クライアントID",
    "Client secret" : "クライアント秘密キー",
    "OpenStack" : "OpenStack",
    "Tenant name" : "テナント名",
    "Identity endpoint URL" : "認証エンドポイントURL",
    "Rackspace" : "Rackspace",
    "API key" : "APIキー",
    "RSA public key" : "RSA公開鍵",
    "Public key" : "公開鍵",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "バケット名",
    "Hostname" : "ホスト名",
    "Port" : "ポート",
    "Region" : "リージョン",
    "Enable SSL" : "SSLを有効",
    "Enable Path Style" : "パス形式を有効",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "リモートサブフォルダー",
    "Secure https://" : "セキュア https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "ローカル",
    "Location" : "場所",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "ホスト",
    "Root" : "ルート",
    "SFTP with secret key login" : "秘密鍵でSFTPログイン",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "共有",
    "Domain" : "ドメイン",
    "SMB / CIFS using OC login" : "ownCloudログインを利用したSMB / CIFS",
    "Username as share" : "共有名",
    "OpenStack Object Storage" : "OpenStack ObjectStorage",
    "Service name" : "サービス名",
    "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
    "<b>Note:</b> " : "<b>注意:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> PHPにcURLのエクステンションが入っていないか、有効ではありません。%s をマウントすることができません。このシステムの管理者にインストールをお願いしてください。",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> \"%s\" がインストールされていません。%sをマウントできません。このシステムの管理者にインストールをお願いしてください。",
    "No external storage configured" : "外部ストレージは設定されていません",
    "You can add external storages in the storage settings" : "ストレージ設定で外部ストレージを設定することができます。",
    "Name" : "名前",
    "Storage type" : "ストレージ種別",
    "Scope" : "スコープ",
    "Enable encryption" : "暗号化を有効に",
    "Enable previews" : "プレビューを有効に",
    "Enable sharing" : "共有の有効化",
    "Check for changes" : "変更点を確認",
    "Never" : "更新無",
    "Once every direct access" : "直指定時のみ",
    "External Storage" : "外部ストレージ",
    "Enable external storage" : "外部ストレージを有効化",
    "External storage has been disabled by the administrator" : "外部ストレージが管理者によって無効化されました",
    "Folder name" : "フォルダー名",
    "Authentication" : "認証",
    "Configuration" : "設定",
    "Available for" : "利用可能",
    "Add storage" : "ストレージを追加",
    "Advanced settings" : "詳細設定",
    "Delete" : "削除",
    "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する"
},
"nplurals=1; plural=0;");
